Usage
=======================

Launch jupyter lab or notebook and navigate to Griottes/example notebooks folder
Try interactive version in `Binder <https://mybinder.org/v2/gh/BaroudLab/Griottes.git/main>`_


.. toctree::
   :maxdepth: 3

   Figure_2

   Figure_3

   Figure_4